@@ -18,9 +18,15 @@ BLACKLIST="totalLength,section5Length,section7Length,dataRepresentationTemplateN
 infile=${data_dir}/ccsds.grib2
 outfile1=temp.$label.1
 outfile2=temp.$label.2
+logfile=temp.$label.log
 
 rm -f $outfile1 $outfile2
 
+# Convert a non-constant grib2 file (Note: not using -r)
+grib2_sample=$ECCODES_SAMPLES_PATH/gg_sfc_grib2.tmpl
+${tools_dir}/grib_set -s packingType=grid_ccsds $grib2_sample $outfile1
+${tools_dir}/grib_compare -c data:n $grib2_sample $outfile1
+
 
 # ECC-1263
 # ---------
@@ -77,8 +83,8 @@ fi
 rm -f $outfile1 $outfile2
 
 infile=${data_dir}/reduced_latlon_surface.grib2
-outfile1=$infile.tmp_ccsds.1
-outfile2=$infile.tmp_ccsds.2
+#outfile1=$infile.tmp_ccsds.1
+#outfile2=$infile.tmp_ccsds.2
 
 ${tools_dir}/grib_set -r -s packingType=grid_ccsds $infile $outfile1
 ${tools_dir}/grib_compare -b $BLACKLIST $infile $outfile1 > $REDIRECT
@@ -96,8 +102,8 @@ rm -f $outfile1 $outfile2
 # ECC-297: Basic support
 # --------------------------------------
 infile=${data_dir}/tigge_ecmwf.grib2
-outfile1=$infile.tmp_ccsds.1
-outfile2=$infile.tmp_ccsds.2
+#outfile1=$infile.tmp_ccsds.1
+#outfile2=$infile.tmp_ccsds.2
 
 ${tools_dir}/grib_set -r -s bitsPerValue=17 $infile $outfile1
 ${tools_dir}/grib_set -r -s packingType=grid_ccsds $outfile1 $outfile2
@@ -138,6 +144,41 @@ grib_check_key_equals $outfile2 packingType grid_ccsds
 ${tools_dir}/grib_compare -b $BLACKLIST  $infile   $outfile1
 ${tools_dir}/grib_compare -c data:n      $outfile1 $outfile2
 
+# Test increasing bitsPerValue
+# -----------------------------
+ifs_dir=${proj_dir}/ifs_samples/grib1_mlgrib2_ccsds
+inputs="
+  $data_dir/ccsds.grib2
+  $ifs_dir/gg_ml.tmpl
+  $ifs_dir/gg_sfc_grib2.tmpl
+"
+grib_check_key_equals $data_dir/ccsds.grib2      'bitsPerValue,packingType,AEC_DATA_3BYTE_OPTION_MASK' '14 grid_ccsds 0'
+grib_check_key_equals $ifs_dir/gg_ml.tmpl        'bitsPerValue,packingType,AEC_DATA_3BYTE_OPTION_MASK' '16 grid_ccsds 1'
+grib_check_key_equals $ifs_dir/gg_sfc_grib2.tmpl 'bitsPerValue,packingType,AEC_DATA_3BYTE_OPTION_MASK' '16 grid_ccsds 1'
+
+MAX_BPV=32 # libaec cannot handle more than this
+
+for input in $inputs; do
+  MIN_BPV=`${tools_dir}/grib_get -p bitsPerValue $input`
+  stats1=`${tools_dir}/grib_get -F%.3f -p min,max,avg,sd $input`
+  for bpv in `seq $MIN_BPV $MAX_BPV`; do
+      ${tools_dir}/grib_set -s setBitsPerValue=$bpv $input $outfile2
+      ${tools_dir}/grib_compare -c data:n $input $outfile2
+      stats2=`${tools_dir}/grib_get -F%.3f -p min,max,avg,sd $outfile2`
+      [ "$stats1" = "$stats2" ]
+      rm -f $outfile2
+  done
+done
+
+# Invalid bitsPerValue (>32)
+# --------------------------
+input=${data_dir}/ccsds.grib2
+set +e
+${tools_dir}/grib_set -s setBitsPerValue=33 $input $outfile2 2> $logfile
+status=$?
+set -e
+[ $status -ne 0 ]
+grep -q "Invalid number of bits per value" $logfile
 
 # ECC-1362
 # ---------
@@ -145,6 +186,14 @@ infile=${data_dir}/ccsds_szip.grib2
 res=`${tools_dir}/grib_get '-F%.3f' -p min,max,avg $infile`
 [ "$res" = "-180.000 180.000 -0.044" ]
 
+# Conversion from JPEG to CCSDS (binaryScaleFactor=0, decimalScaleFactor!=0)
+# -------------------------------------------------------------------------
+if [ $HAVE_JPEG -eq 1 ]; then
+  ${tools_dir}/grib_copy -w count=2 ${data_dir}/v.grib2 $outfile1
+  grib_check_key_equals $outfile1 packingType,bitsPerValue,binaryScaleFactor,decimalScaleFactor 'grid_jpeg 10 0 1'
+  ${tools_dir}/grib_set -r -s packingType=grid_ccsds $outfile1 $outfile2
+  ${tools_dir}/grib_compare -c data:n $outfile1 $outfile2
+fi
 
 # Clean up
-rm -f $outfile1 $outfile2
+rm -f $outfile1 $outfile2 $logfile
